==> contentsquare-1.1.0.tar.gz: lib/src/modules/webview_tracking/javascript_event_handler.dart <==
import 'dart:convert';

import 'package:contentsquare/contentsquare.dart';
import 'package:contentsquare/src/obfuscation/keep.dart';
import 'package:flutter/foundation.dart';
import 'package:webview_flutter/platform_interface.dart';

import 'adapters/adapters.dart';

/// The type of event that is sent from the webview.
@a273
enum ContentsquareJavascriptEventEnum {
  /// Send a pageView event or any kind of gesture.
  sendEvent,

  /// Send an exception.
  sendException,

  /// Send a message.
  sendMessage,

  /// Opt in.
  optIn,

  /// Opt out.
  optOut,

  /// Send transaction.
  sendTransaction,

  /// Send dynamic var.
  sendDynamicVar,
}


const _a363 =
    'CSJavascriptBridge_FlutterJavascriptChannel_';


@visibleForTesting
class a149 {
  
  a149({
    required this.a57,
    required this.a56,
    required this.a55,
  });

  
  final Contentsquare a57;

  
  final ContentsquareJavascriptEventEnum a56;

  
  String get _a248 =>
      '$_a363${a56.name}';

  
  final String? Function() a55;

  
  JavascriptChannel get a2 {
    return JavascriptChannel(
      name: _a248,
      onMessageReceived: (message) async {
        return _a249(message);
      },
    );
  }

  
  Future<void> _a249(JavascriptMessage a516) {
    final a364 = jsonDecode(a516.message) as Map<String, dynamic>;
    return _a250(a57).a13(a364);
  }

  a168 _a250(Contentsquare a517) {
    switch (a56) {
      case ContentsquareJavascriptEventEnum.sendEvent:
        return a159(
          a51: a517,
          a50: a55,
        );
      case ContentsquareJavascriptEventEnum.sendException:
        return a165(a47: a517);
      case ContentsquareJavascriptEventEnum.sendMessage:
        return a164(a48: a517);
      case ContentsquareJavascriptEventEnum.optIn:
        return a151(a54: a517);
      case ContentsquareJavascriptEventEnum.optOut:
        return a153(a53: a517);
      case ContentsquareJavascriptEventEnum.sendTransaction:
        return a167(a45: a517);
      case ContentsquareJavascriptEventEnum.sendDynamicVar:
        return a166(a46: a517);
    }
  }

  
  String get a1 => '''
function (${_a250(a57).a0.map((name) => name).join(', ')}) {
  window.$_a248.postMessage(
    JSON.stringify({${_a250(a57).a0.map((name) => '"$name": $name').join(', ')}})
  );
}''';
}

==> contentsquare-1.2.0.tar.gz: lib/src/modules/webview_tracking/javascript_event_handler.dart <==
import 'dart:convert';

import 'package:contentsquare/contentsquare.dart';
import 'package:contentsquare/src/obfuscation/keep.dart';
import 'package:flutter/foundation.dart';

import 'adapters/adapters.dart';

/// The type of event that is sent from the webview.
@a271
enum ContentsquareJavascriptEventEnum {
  /// Send a pageView event or any kind of gesture.
  sendEvent,

  /// Send an exception.
  sendException,

  /// Send a message.
  sendMessage,

  /// Opt in.
  optIn,

  /// Opt out.
  optOut,

  /// Send transaction.
  sendTransaction,

  /// Send dynamic var.
  sendDynamicVar,
}


const _a363 =
    'CSJavascriptBridge_FlutterJavascriptChannel_';


@visibleForTesting
class a147 {
  
  a147({
    required this.a57,
    required this.a56,
    required this.a55,
  });

  
  final Contentsquare a57;

  
  final ContentsquareJavascriptEventEnum a56;

  
  String get _a242 =>
      '$_a363${a56.name}';

  
  final String? Function() a55;

  
  JavascriptChannel get a1 {
    return JavascriptChannel(
      name: _a242,
      onMessageReceived: (message) async {
        return _a243(message);
      },
    );
  }

  
  Future<void> _a243(String a516) {
    final a364 = jsonDecode(a516) as Map<String, dynamic>;
    return _a244(a57).a12(a364);
  }

  a166 _a244(Contentsquare a517) {
    switch (a56) {
      case ContentsquareJavascriptEventEnum.sendEvent:
        return a157(
          a51: a517,
          a50: a55,
        );
      case ContentsquareJavascriptEventEnum.sendException:
        return a163(a47: a517);
      case ContentsquareJavascriptEventEnum.sendMessage:
        return a162(a48: a517);
      case ContentsquareJavascriptEventEnum.optIn:
        return a149(a54: a517);
      case ContentsquareJavascriptEventEnum.optOut:
        return a151(a53: a517);
      case ContentsquareJavascriptEventEnum.sendTransaction:
        return a165(a45: a517);
      case ContentsquareJavascriptEventEnum.sendDynamicVar:
        return a164(a46: a517);
    }
  }

  
  String a20({
    required String Function(String channelName, String data)
        a434,
  }) =>
      '''
function (${_a244(a57).a0.map((name) => name).join(', ')}) {
  ${a434(_a242, 'JSON.stringify({${_a244(a57).a0.map((name) => '"$name": $name').join(', ')}})')};
}''';
}
